.. expect: missing space before < in hyperlink
.. expect: missing underscore after closing backtick in hyperlink

.. and yes, it very looks like a default role, so we get this too:
.. expect: default role used

This combines two mistakes: missing an underscore at the end and
forgetting the space before the opening bracket:

`Link text<https://example.com>`
